
.. _auxiliaries:

Auxiliary Tools
===============

The `auxs` subpackage provides features that are not essential for the
functionality of *HydPy* in general, but possibly provide help when
implementing new models or writing *HydPy* workflow scripts.

Albeit of the small number of modules contained in subpackage `auxs`
so far, the features they provide are very diverse.  A short look
into the general description of each module should help to find out
what purpose it could serve.

.. toctree::
   :hidden:

   anntools
   armatools
   iuhtools
   networktools
   roottools
   smoothtools
   statstools
   validtools
   xmltools
